# gsloc: Apple Location Service API for Python

This is a Python library that provides a reverse engineered implementation of the Apple Location Service API.

## Installation

```bash
pip install gsloc
```

## Usage
